@@ -18,8 +18,8 @@ $absmin = "";
 $chancefile; 
 $reportfile = "";
 $steps = 3;
-@midvalues = (2, 2); # POINT TO POINT CORRENSPODENCE WITH THE ABOVE. THE MID ITERATION NUMBER FOR EACH PARAMETER.
-# I.E. THREE ITERATION PER PARAMETER, VALUE "2" FOR EACH $midvalue (@midvalues). 
+@midvalues = (2, 2); # POINT TO POINT CORRENSPODENCE WITH THE ABOVE, and with the variables $setvar (see below). THE MID ITERATION NUMBER FOR EACH PARAMETER. 
+# I.E. IF THERE ARE 3 ITERATION PER PARAMETER, A VALUE "2" FOR EACH $midvalue (@midvalues) HAS TO BE SPECIFIED.  
 
 @casegroup = ( [ [4, 4] ] ) ; # BETWEEN SQUARE BRACKETS ARE THE BLOCKS OF BLOCK COORDINATE SEARCH. THE FIRST ITEM IN 
 # EACH SQUARE BRACKET IS THE POSITION OF THE FIRST ITEM IN THE ACTIVE BLOCK (INDEX FROM 0). THE SECOND ITEM IS THE DIMENSION OF THE ACTIVE BLOCK,
